%% Field of a s pherically focused transducer

%%% Set parameters
f=2e6; % Frequency
a = 10*1e-3; % 20 mm diameter (a is the radius)
c=1500; % Speed of sound in water
F=15e-3; % Focal distance (in m) %%%%% YOU NEED TO CHANGE THIS FOR b)!

% Related parameters
lambda=c/f;
k=(2*pi)/lambda;

%%% Choose a region to calculate the field (NB! This code is quite slow, so
%%% choose your region wisely!)

% Choose a region around the focal distance (in the depth direction)(z=0
% is the transducer surface
z_vec=[0.010:0.000025:0.020]'; % Suitable for F = 15 mm %%%%% YOU NEED TO CHANGE THIS FOR b)!


% Choose a width to calculate the field, x=0 is the centre axis
x0_vec=[-0.002:0.000025:0.002]; % Suitable for f=2MHz

%%% Initialize an array with the field values (field, not intensity)
% Each row corresponds to one depth
PHI_v1=zeros(length(z_vec),length(x0_vec));

%%% This for-loop calculates the field at each point
for n=1:length(z_vec)
    for m=1:length(x0_vec)
        %%% Simple notation so it is easy to follow/read
        z=z_vec(n);
        x0=x0_vec(m);
        const=(k/(1i*z))*exp(1i*k*( z + ((x0^2)/(2*z)) ));
        % This is the function to integrate over the surface of the
        % transducer
        fun1 = @(r)...
            exp( ((1i*k*r.^2)./(2*F)).*((F/z)-1) ).*(besselj(0,((k*x0.*r)./z))).*r;
        % Integration is performed from 0 to a
        int_term=integral(fun1,0,a,'RelTol',0,'AbsTol',1e-14);
        PHI_v1(n,m)=const.*int_term;
        
%         fprintf('n= %i\n',n); % This code takes a few minutes to run. If
%         you want to know how it's proceeding, uncomment line 42 to find
%         out the row (the index of z) that is being calculated

    end
end


%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% TASKS (1-3 the same for a) and b))

%%% Task 1: Plot the intensity field (with the correct x and z coordinates
%%% and axis labels)

%%% NB! The field in PHI_v1 is a complex field (complex amplitude). You
%%% want to plot intensity (does not need to be properly normalized).

% Hint: imagesc



%%% Task 2: Determine the -3 dB lateral focal width from the image




%%% Task 3: Determine the -3 dB depth-of-focus (axial focal width)

 

%%% Task 4: Compare your simulated values, values obtained by (62) and (69)
%%% in Gohari and Hussein and for a flat (unfocused) transducer. (Olympus
%%% leaflet, eqs. 8a and 9 (NB! Olympus uses amplitudes, not intensity, so
%%% -6 dB there corresponds to -3 dB here))








